OptRecordDiff

Enum OptRecordDiff 

pub enum OptRecordDiff<R>
where R: Node,
{ Clear, Update(<R as Node>::Diff), }
Represent a delta between two optional records X and Y.

Variants



Clear

To obtain Y from X, clear the optional record (if any)



Update(<R as Node>::Diff)

To obtain Y from X, apply the given diff on the record contained in X.

If X does not contain a record, the record diff represents the delta between the default value R and the value contained in Y.